@@ -113,7 +113,7 @@ class CharLanguage(Language):
         )
 
     def encode(self, s: str) -> List[int]:
-        return [self.stot[s] for s in s]
+        return [self.stot[c] for c in s]
 
 
 class Sampler:
